@@ -296,7 +296,7 @@
 //! [`simple-eyre`]: https://github.com/yaahc/simple-eyre
 //! [`color-spantrace`]: https://github.com/yaahc/color-spantrace
 //! [`color-backtrace`]: https://github.com/athre0z/color-backtrace
-#![doc(html_root_url = "https://docs.rs/eyre/0.6.6")]
+#![doc(html_root_url = "https://docs.rs/eyre/0.6.7")]
 #![warn(
     missing_debug_implementations,
     missing_docs,
@@ -820,7 +820,7 @@ pub struct Chain<'a> {
 ///
 /// # const IGNORE: &str = stringify! {
 /// fn demo1() -> Result<T> {...}
-///            // ^ equivalent to std::result::Result<T, eyre::Error>
+///            // ^ equivalent to std::result::Result<T, eyre::Report>
 ///
 /// fn demo2() -> Result<T, OtherError> {...}
 ///            // ^ equivalent to std::result::Result<T, OtherError>
@@ -936,7 +936,7 @@ pub type Result<T, E = Report> = core::result::Result<T, E>;
 /// # Effect on downcasting
 ///
 /// After attaching a message of type `D` onto an error of type `E`, the resulting
-/// `eyre::Error` may be downcast to `D` **or** to `E`.
+/// `eyre::Report` may be downcast to `D` **or** to `E`.
 ///
 /// That is, in codebases that rely on downcasting, Eyre's wrap_err supports
 /// both of the following use cases:
@@ -1153,6 +1153,7 @@ pub mod private {
 
     #[doc(hidden)]
     #[cold]
+    #[cfg_attr(track_caller, track_caller)]
     pub fn format_err(args: Arguments<'_>) -> Report {
         #[cfg(eyre_no_fmt_arguments_as_str)]
         let fmt_arguments_as_str: Option<&str> = None;
